import request from '@/utils/request'

export function createItem(data) {
  return request({
    url: '/mall-draw-pool/add',
    method: 'post',
    data
  })
}

export function updateItem(data) {
  return request({
    url: '/mall-draw-pool/edit',
    method: 'post',
    data
  })
}

export function list(query) {
  return request({
    url: '/mall-draw-pool/list',
    method: 'get',
    params:query
  })
}

export function deleteitem(query) {
  return request({
    url: '/mall-draw-pool/remove',
    method: 'post',
    params:query
  })
}

export function optionSelect(data) {
  return request({
    url: '/mall-draw-pool/optionselect',
    method: 'get',
    data
  })
}
export function dataList(query) {
  return request({
    url: '/mall-draw-pool-data/list',
    method: 'get',
    params:query
  })
}
export function dataAdd(data) {
  return request({
    url: '/mall-draw-pool-data/add',
    method: 'post',
    data
  })
}
export function dataEdit(data) {
  return request({
    url: '/mall-draw-pool-data/edit',
    method: 'post',
    data
  })
}
export function dataRemove(query) {
  return request({
    url: '/mall-draw-pool-data/remove',
    method: 'post',
    params:query
  })
}

export function logsList(query) {
  return request({
    url: '/MidAutumn/Activity/midAutumn/list',
    method: 'get',
    params:query
  })
}






