<template>
    <div class="app-container calendar-list-container">

        <!-- 查询和其他操作 -->
        <div class="filter-container">
            <el-select @change="changeDictType" v-model="listQuery.dictType" clearable placeholder="字典名称" class="filter-item" style="width: 200px">
                <el-option :key="item.dictType" v-for="item in dictNameList" :label="item.dictName" :value="item.dictType">
                </el-option>
            </el-select>
            <el-input clearable class="filter-item" style="width: 200px;" placeholder="请输入字典标签"
                v-model="listQuery.dictLabel"></el-input>
                <el-select v-model="listQuery.status" clearable placeholder="状态" class="filter-item" style="width: 200px">
                <el-option :key="item.type" v-for="item in typeList" :label="item.name" :value="item.type">
                </el-option>
            </el-select>
            <el-button class="filter-item" type="primary" v-waves icon="el-icon-search" @click="handleFilter">查找</el-button>
            <el-button class="filter-item" type="primary" @click="handleCreate" icon="el-icon-edit">添加</el-button>
            <el-button class="filter-item" type="warning" icon="el-icon-delete" @click="delAll">批量删除</el-button>

        </div>

        <!-- 查询结果 -->
        <el-table size="small" :data="list" v-loading="listLoading" @selection-change="handleSelectionChange"
            element-loading-text="正在查询中。。。" border fit highlight-current-row>
            <el-table-column type="selection" width="55px"> </el-table-column>
            <el-table-column align="center" min-width="60px" label="字典编码" prop="dictCode">
            </el-table-column>
            <el-table-column align="center" min-width="100px" label="字典标签" prop="dictLabel">
            </el-table-column>
            <el-table-column align="center" min-width="60px" label="字典键值" prop="dictValue">
            </el-table-column>
            <el-table-column align="center" min-width="60px" label="字典排序" prop="dictSort">
            </el-table-column>
            <el-table-column align="center" min-width="100px" label="状态">
            <template slot-scope="scope">
                <el-tag v-if="scope.row.status == '0'">正常</el-tag>
                <el-tag v-else>停用</el-tag>
            </template>
        </el-table-column>
        <el-table-column align="center" min-width="200px" label="备注" prop="remark">
        </el-table-column>
        <el-table-column align="center" min-width="100px" label="创建时间" prop="createTime">
        </el-table-column>
            <el-table-column align="center" label="操作" width="240px" class-name="small-padding fixed-width">
                <template slot-scope="scope">
                    <el-button type="primary" size="small" @click="handleUpdate(scope.row, false)">编辑</el-button>

                    <el-button type="danger" size="small" @click="handleDelete(scope.row)">删除</el-button>
                </template>
            </el-table-column>
        </el-table>

        <!-- 分页 -->
        <div class="pagination-container">
            <el-pagination background @size-change="handleSizeChange" @current-change="handleCurrentChange"
                :current-page="listQuery.page" :page-sizes="[10, 20, 30, 50]" :page-size="listQuery.limit"
                layout="total, sizes, prev, pager, next, jumper" :total="total">
            </el-pagination>
        </div>

        <!-- 添加或修改对话框 -->
        <el-dialog
        :close-on-click-modal="false"
        :title="textMap[dialogStatus]"
        :visible.sync="dialogFormVisible"
        width="40%"
      >
        <el-form :rules="rules" ref="dataForm" :model="dataForm" status-icon label-position="left" label-width="80px" style='width: 700px; margin-left:50px;'>
            <el-form-item  label="字典类型" prop="dictType">
              <el-input disabled style="width: 300px" v-model="dataForm.dictType"></el-input>
            </el-form-item>
            <el-form-item  label="字典标签" prop="dictLabel">
              <el-input style="width: 300px" v-model="dataForm.dictLabel"></el-input>
            </el-form-item>
            <el-form-item  label="字典键值" prop="dictValue">
               <el-upload  v-if="['index_lbt', 'publicize_banner', 'activity_banner'].includes(dataForm.dictType)"
                            :limit="1" :action="fileImgUrl"
                            list-type="picture-card"
                            :file-list="dataForm.images"
                            :on-success="handleGallerySucess"
                            :on-exceed="handleExceed"
                            :before-upload="uploadBannerImg"
                            :on-remove="handleRemove">
                             <i class="el-icon-plus"></i>
              </el-upload>
              <el-input  v-else style="width: 300px" v-model="dataForm.dictValue"></el-input>
            </el-form-item>
            <el-form-item label="显示排序" prop="dictSort">
                <el-input-number
                  :precision="0"
                  :step="1"
                  v-model="dataForm.dictSort"
                ></el-input-number>
              </el-form-item>
            <el-form-item  label="状态">
                <el-radio-group v-model="dataForm.status">
                    <el-radio :label="'0'">正常</el-radio>
                    <el-radio :label="'1'">停用</el-radio>
                </el-radio-group>
            </el-form-item>
            <el-form-item  label="备注">
              <el-input type="textarea" :rows="2" style="width: 300px" v-model="dataForm.remark"></el-input>
            </el-form-item>


        </el-form>
        <div slot="footer" class="dialog-footer">
          <el-button @click="dialogFormVisible = false">取消</el-button>
          <el-button v-if="dialogStatus == 'create'" type="primary" @click="createData">确定</el-button>
          <el-button v-else type="primary" @click="updateData">确定</el-button>
        </div>
      </el-dialog>

    </div>
</template>

<style>
.demo-table-expand {
    font-size: 0;
}

.demo-table-expand label {
    width: 200px;
    color: #99a9bf;
}

.demo-table-expand .el-form-item {
    margin-right: 0;
    margin-bottom: 0;
}
</style>

<script>
import { dataList, dataAdd, dataEdit, dataRemove, optionSelect } from "@/api/dictManage";
import waves from "@/directive/waves"; // 水波纹指令
import Tinymce from '@/components/Tinymce'

export default {
    components: { Tinymce },
    directives: { waves },
    data() {
        return {
            dictType:'',
            dictNameList: [],
            typeList: [
                {
                    type: '0',
                    name: "正常",
                },
                {
                    type: '1',
                    name: "停用",
                },
            ],
            list: [
            ],
            delarr: [],
            multipleSelection: [],
            total: 0,
            listLoading: false,
            listQuery: {
                page: 1,
                limit: 10,
                dictType: '',
                dictLabel: '',
                status: '',
            },
            dataForm: {
                dictType: undefined,
                dictLabel: undefined,
                dictValue: '',
                images: [],
                dictSort: undefined,
                status: '0',
                remark: undefined,
            },
            dialogFormVisible: false,
            dialogStatus: '',
            textMap: {
                update: "编辑",
                create: "创建",
            },
            imageUrl: undefined,
            rules: {
                dictLabel: [{ required: true, message: "字典标签不能为空", trigger: "blur" }],
                dictValue: [{ required: true, message: "字典键值不能为空", trigger: "blur" }],
                dictSort: [{ required: true, message: "显示排序不能为空", trigger: "blur" }],

            },
            fileImgUrl: this.upLoadUrl,
        }
    },
    created() {
        this.dictType = this.$route.params.id;
        this.getOptionSelect();
    },
    methods: {

        changeDictType(val){
            this.dictType = val;
            this.listQuery.dictType = val;
            this.getList();
        },
        getOptionSelect(){
            optionSelect().then(response => {
                this.dictNameList = response.data.data;
                this.listQuery.dictType = this.dictType;
                this.getList();
            }).catch(() => {})
        },
        resetForm() {
            this.dataForm = {
                dictType: undefined,
                dictLabel: undefined,
                dictValue: '',
                images: [],
                dictSort: undefined,
                status: '0',
                remark: undefined,
            };
        },
        handleCreate() {
            this.resetForm();
            this.dataForm.dictType = this.dictType;
            this.dialogFormVisible = true;
            this.dialogStatus = "create";
            this.$nextTick(() => {
                this.$refs["dataForm"].clearValidate();
            });
        },
        createData() {
            this.$refs["dataForm"].validate((valid) => {
                if (valid) {
                    dataAdd(this.dataForm)
                        .then(() => {
                            this.getList();
                            this.dialogFormVisible = false;

                            this.$notify({
                                title: "成功",
                                message: "创建成功",
                                type: "success",
                                duration: 2000,
                            });
                            this.getList()
                        })
                }
            });
        },
        getList() {
            this.listLoading = true
            dataList(this.listQuery).then(response => {
                this.list = response.data.data.items
                this.total = response.data.data.total
                this.listLoading = false
            }).catch(() => {
                this.list = []
                this.total = 0
                this.listLoading = false
            })
        },

        handleFilter() {
            this.listQuery.page = 1
            this.getList()
        },

        handleSizeChange(val) {
            this.listQuery.limit = val
            this.getList()
        },

        handleCurrentChange(val) {
            this.listQuery.page = val
            this.getList()
        },

        handleUpdate(row) {
            this.dataForm = Object.assign({}, row);
            if (this.dataForm.dictValue) {
                            let images = this.dataForm.dictValue.split(",");
                            this.dataForm.images = [];
                            for (let i in images) {
                                let url = images[i];
                                let name = "image_" + i;

                                this.dataForm.images.push({
                                    name: name,
                                    url: url,
                                    response: { error: "0", data: { url: url } },
                                });
                            }
                        }
            this.dialogStatus = 'update'
            this.dialogFormVisible = true
            this.$nextTick(() => {
                this.$refs['dataForm'].clearValidate()
            })
        },

        updateData() {
            this.$refs['dataForm'].validate((valid) => {
                if (valid) {
                    dataEdit(this.dataForm).then(() => {
                        this.dialogFormVisible = false
                        this.$notify({
                            title: '成功',
                            message: '更新成功',
                            type: 'success',
                            duration: 2000
                        })
                        this.getList()
                    })

                }
            })
        },

        handleDelete(row) {

            this.$confirm('确认删除吗?', '提示', {
                confirmButtonText: '确定',
                cancelButtonText: '取消',
                type: 'warning'
            }).then(() => {
                dataRemove({ dictCodes:row.dictCode}).then(response => {
                    this.$notify({
                        title: '成功',
                        message: '删除成功',
                        type: 'success',
                        duration: 2000
                    })
                    const index = this.list.indexOf(row)
                    this.list.splice(index, 1)
                })
            }).catch(() => {

            })

        },
        delAll() {
            this.$confirm("确认删除吗?", "提示", {
                confirmButtonText: "确定",
                cancelButtonText: "取消",
                type: "warning",
            })
                .then(() => {
                    const length = this.multipleSelection.length;

                    if (length > 0) {
                        for (let i = 0; i < length; i++) {
                            this.delarr.push(this.multipleSelection[i].dictCode);
                        }
                        const  dictCodes = this.delarr.join(",");
                        dataRemove({  dictCodes:  dictCodes })
                            .then(() => {
                                this.$notify({
                                    title: "成功",
                                    message: "删除成功",
                                    type: "success",
                                    duration: 2000,
                                });
                                this.getList();
                            })
                            .catch(() => { });
                    } else {
                        this.$notify({
                            title: "警告提示",
                            message: "请选择要删除的信息！",
                            type: "warning",
                        });
                    }
                })
                .catch(() => { });
        },
        handleSelectionChange(val) {
            this.multipleSelection = val;
        },
        uploadBannerImg(file) {
                    const isJPGs = file.type === "image/jpeg";
                    console.log(isJPGs);
                },
        handleExceed(files, fileList) {
                    this.$message.warning(
                        `当前限制选择 1 个文件，本次选择了 ${files.length} 个文件！，共选择了 ${files.length + fileList.length
                        } 个文件`
                    );
                },
        handleGallerySucess(res, file, fileList) {
                    this.dataForm.dictValue = ""; // 清空画廊图片数组

                    let images = [];
                    for (let i in fileList) {
                        let response = fileList[i].response;
                        if (response.errno && response.errno != "0") {
                            this.$message.error("该图片上传失败,已被移除,请重新上传!");
                            // 上传失败移除该 file 对象
                            fileList.splice(i, 1);
                        } else {
                            let url = response.data.url;
                            images.push(url);
                        }
                    }

                    this.dataForm.dictValue = images.join(",");
                },
                handleRemove(file, fileList) {
                            console.log(file, fileList);
                            let images = [];
                            for (let i in fileList) {
                                let response = fileList[i].response;
                                let url = response.data.url;
                                images.push(url);
                                this.dataForm.dictValue = images.join(",");
                            }
                        },
    }
}
</script>
<style>
.ad-avatar-uploader .el-upload {
    border: 1px dashed #d9d9d9;
    border-radius: 6px;
    cursor: pointer;
    position: relative;
    overflow: hidden;
}

.ad-avatar-uploader .el-upload:hover {
    border-color: #409EFF;
}

.ad-avatar-uploader-icon {
    font-size: 28px;
    color: #8c939d;
    width: 178px;
    height: 178px;
    line-height: 178px;
    text-align: center;
}

.ad-avatar {
    display: block;
}
</style>
